# -*- coding: utf-8 -*-

# Copyright 2006-2012 Borislav Rizov <bobyATdclDOTbasDOTbg>, Department of Computational Linguistic, Institute for Bulgarian Language – Bulgarian Academy of Sciences
# 
# This file is part of Chooser.
# 
# Chooser is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Chooser is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with Chooser.  If not, see <http://www.gnu.org/licenses/>.

from Tkinter import *
from Tix import ScrolledListBox
from hydra.observer_context import *
NUM_PREFIX = 4
class ChoiceView(Context,  Frame):
	def __init__(self,  master,  ruler):
		Context.__init__(self)
		Frame.__init__(self,  master)
		self.ruler = ruler
		self.create_widgets()
		self.sel = None
	def create_widgets(self):
		self.slistbox= ScrolledListBox(self.master,  command = self.select,  browsecmd = self.browse)
		self.slistbox.pack(expand = 1,  fill = BOTH)
		self.listbox = self.slistbox.listbox
		self.winfo_toplevel().bind('<Key>',  self.on_key)
	def on_key(self,  event):
		sel = self.denumerate(event.char)
		if sel != None and sel <= len(self.synsets):
			self._select(sel)
	def get_sel(self):
		sels = (self.listbox.curselection())
#		print sels,  'sels',  bool(sels)
		if sels:
			return int(sels[0])
	def browse(self):
		sel = self.get_sel()
		if sel != None and self.sel != sel:
			self.notify(VMessage(self.synsets[sel]))
			self.sel = sel
	def _select(self,  sel):
		self.word.select(self.synsets[sel],  True)
#		self.highlight(sel)
#		print self.synsets[sel].to_string('ili')
		#NB
		self.ruler.on_select()
	def select(self):
		sel = self.get_sel()
		if sel != None:
			self._select(sel)
#		print 'select'
	def highlight(self,  i):
		self.listbox.itemconfig(i,  bg='red',  fg = 'white')
	def denumerate(self,  ch):
		if ch:
			c = ord(ch)
			if c >= ord('1') and c <= ord('9'):
				return c - ord('1')
			if c >= ord('a') and c <= ord('z'):
				return c - ord('a') + 9
	def enumerate(self,  i,  s):
		i += 1
		if i <= 9 :
			x = `i`
		elif i < 36:
			x = chr(i - 10 + ord('a'))
		else:
			x = ' '
		return x + " " * (NUM_PREFIX - len(x) ) + s
	def draw(self):
		self.listbox.delete(0,  END)
		self.synsets = self.word.synsets()
		for i,  synset in enumerate(self.synsets):
			self.listbox.insert(END,  self.enumerate(i,  synset.to_string('definition')))
			if self.word.synset and synset.ID() == self.word.synset.ID():
				self.highlight(i)
	def refresh(self,  message):
		self.word = message.data
#		print self.word.user
		self.draw()
		self.sel = None
if __name__ == '__main__':
	main = Tk()
#	Button(main,  text = 'test').pack()
	
	ch = ChoiceView(main,  main)
	ch.pack()
	main.mainloop()
