# -*- coding: utf-8 -*-

# Copyright 2006-2012 Borislav Rizov <bobyATdclDOTbasDOTbg>, Department of Computational Linguistic, Institute for Bulgarian Language – Bulgarian Academy of Sciences
# 
# This file is part of Chooser.
# 
# Chooser is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Chooser is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with Chooser.  If not, see <http://www.gnu.org/licenses/>.

from hydra.wordnet import *
import time

class Word(object):
    def __init__(self, w, l,  tag,  parent =  None):
        self.parent = parent
        self.word = w
        self.lemma = l
        self.tag = `tag`
        self._init(parent)
    def set_end(self,  value):
        self.end = value
    def _init(self,  parent = None):
        self.synset = None
        self.user  = None
        self.time = None
        self.parent = parent
        self.end = None
    def form(self):
        return self.word
    def literal(self):
        return self.lemma
    def compare(self,  s1,  s2):
        return s2.frequency()  - s1.frequency()
    def synsets(self):
        return self.senses(sort = True)
#		return sorted(wn.get("<Literal>word('%s')" % self.literal()),  cmp = self.compare)
#        lit = self.literal()
#        if lit.strip():
#            return sorted(wn.get("<Literal>lemma('%s')" % self.literal()),  cmp = self.compare)
#        return []
    def senses(self,  sort = False):
        lit = self.literal()
        if lit:
            res = wn.get("<Literal>lemma('%s')" % lit)
        else:
            res = []
        if sort:
            return sorted(res,  cmp = self.compare)
        return res
    def tags(self):
        return [self.tag]
    def select(self,  synset,  set_frequency = False):
        if self.parent:
            word = self.parent
        else:
            word = self
        if set_frequency:
            if word.synset:
                if word.synset.ID() != synset.ID():
                    word.synset.update_frequency(-1)
                    word.synset = synset
                    word.synset.update_frequency(+1)
            else:
                word.synset = synset
                word.synset.update_frequency(+1)
            word.set_stamp()
        else:
            word.synset = synset
    def stamp(self):
        if self.parent:
            return self.parent.user,  self.parent.time
        else:
            return self.user,  self.time
    def set_stamp(self):
        self.time = int(time.time())
        self.user = wn.user
    def selected(self):
        if self.parent:
            return self.parent.synset
        else:
            return self.synset
    def set_index(self,  value):
        self.tag = `value`
    def get_index(self):
        return int(self.tag)
    index = property(fget = get_index,  fset = set_index)
    
class Words(Word):
    def __init__(self,  w1, position=None):
        self.words = []
        self._init()
        self.add(w1, position)
        self.lemma = None
        self.word = None
    def selected(self):
        return self.synset
    def add(self,  word, position=None):
        if position!=None:
            self.words.extend([None for i in range(len(self.words), position + 1)])
            self.words[position] = word
        else:
            self.words.append(word)
        word.parent = self
    def remove(self,  word):
        self.words.remove(word)
        word.parent = None
        if len(self.words) == 1:
            self.words[0].parent = None
        return self.words[0]
    def form(self):
        return ' '.join([word.form() for word in self.words])
        return 'WILL BE DISCARDED!'
    def literal(self):
        if self.lemma:
            return self.lemma
        return ' '.join([word.literal() for word in self.words])
    def tags(self):
        return [word.tag for word in self.words]

